.issue {
  padding: 10px;
  display: flex;
  flex-wrap: nowrap;
  column-gap: 10px;

  .rank {
    align-content: center;

    a {
      color: #666;

      @media (prefers-color-scheme: light) {
        color: #bbb;
      }

      &.pin {
        &:hover {
          color: deepskyblue;
        }

        &.enabled {
          color: deepskyblue;
        }
      }

      &.high {
        &:hover {
          color: green;
        }

        &.enabled {
          color: green;
        }
      }

      &.low {
        &:hover {
          color: red;
        }

        &.enabled {
          color: red;
        }
      }
    }
  }

  .title {
    font-weight: 700;

    .icon {
      margin-right: 5px;
    }

    .link {
      text-decoration: none;
      color: unset;

      &:hover {
        text-decoration: underline;
      }
    }
  }

  .metadata {
    font-size: smaller;

    span {
      margin-right: 10px;
    }
  }

  // Mechanism to show new issues, and mark them as seen
  div.markseen {
    margin-left: 10px;
    display: none;
    color: #fff;
  }
  &:target {
    background-color: #404c5f;
    @media (prefers-color-scheme: light) {
      background-color: #d3d1d1;
    }

    .markseen {
      display: inline;
    }
  }
}

button {

  &#mark-as-seen {
    margin-left: 10px;
  }

  &.small {
    padding: 5px 10px;
  }

  &.x-small {
    padding: 0px 5px;
  }
}
